from setuptools import setup, find_packages
setup(
    name='mypackage_manqust',
    version='0.1',
    packages=find_packages(),
    description='mypackage for 11 lab',
    author='Катя',
    author_email='eam49@tpu.ru',
    url='https://example.com/mypackage',
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
    python_requires='>=3.6',
)